Learn R Programming

urca (version 0.2-0)

.spcv: Critical values for Schmidt & Phillips Unit Root Test

Description

This function is an internal function and is called by ur.sp. It computes the critical value of the Schmidt & Phillips test, given a level of significance, the polynomial degree of the test regression, the test type and the sample size.

Usage

.spcv(obs, type = c("tau", "rho"), pol.deg = c(1, 2, 3, 4),
      signif = c(0.01, 0.025, 0.05, 0.1))

Arguments

obs
The sample size.
type
The test type.
pol.deg
The polynomial degree.
signif
The significance level.

Value

  • The critical value of the test.

References

Schmidt, P. and Phillips, P.C.B. (1992), LM Test for a Unit Root in the Presence of Deterministic Trends, Oxford Bulletin of Economics and Statistics, 54(3), 257--287. Download possible at: http://cowles.econ.yale.edu/, see rubric 'Discussion Papers (CFDPs)'.

See Also

ur.sp