Rdocumentation
powered by
Learn R Programming
urca (version 0.2-0)
show.urca: Function to show objects of classes for unit root tests
Description
The function
show.urca
is called within the defined methods for classes
ca.po
,
ur.ers
,
ur.kpss
,
ur.po
,
ur.pp
,
ur.sp
and
ur.za
.
Usage
show.urca(object)
Arguments
object
Object of class contained in
urca
.
Value
The Name and test statistic of a unit root/cointegration test.
Details
This function is called by method
show
.