Learn R Programming

urca (version 0.2-0)

ur.ers-class: Representation of class `ur.ers'

Description

This class contains the relevant information by applying the Elliott, Rothenberg & Stock unit root test.

Arguments

Extends

Class "urca", directly.

References

Elliott, G., Rothenberg, T.J. and Stock, J.H. (1996), Efficient Tests for an Autoregressive Unit Root, Econometrica, Vol. 64, No. 4, 813--836. MacKinnon, J.G. (1991), Critical Values for Cointegration Tests, Long-Run Economic Relationships, eds. R.F. Engle and C.W.J. Granger, London, Oxford, 267--276. Download possible at: http://www.econ.ucsd.edu/papers/files/90-4.pdf.

See Also

ur.ers, urca-class.