Learn R Programming

urca (version 0.2-0)

ur.kpss-class: Representation of class `ur.kpss'

Description

This class contains the relevant information by applying the Kwiatkowski, Phillips, Schmidt & Shin unit root test to a time series.

Arguments

Extends

Class "urca", directly.

References

Kwiatkowski, D., Phillips, P.C.B., Schmidt, P. and Shin, Y., (1992), Testing the Null Hypothesis of Stationarity Against the Alternative of a Unit Root: How Sure Are We That Economic Time Series Have a Unit Root?, Journal of Econometrics, 54, 159--178. Download possible at: http://cowles.econ.yale.edu/, see rubric 'Discussion Papers (CFDPs)'.

See Also

ur.kpss, urca-class.