Learn R Programming

urca (version 0.2-0)

ur.pp-class: Representation of class `ur.pp'

Description

This class contains the relevant information by applying the Phillips & Perron Unit Root Test to a time series.

Arguments

Extends

Class "urca", directly.

References

Phillips, P.C.B. and Perron, P. (1988), Testing for a unit root in time series regression, Biometrika, 75(2), 335--346. MacKinnon, J.G. (1991), Critical Values for Cointegration Tests, Long-Run Economic Relationships, eds. R.F. Engle and C.W.J. Granger, London, Oxford, 267--276. Download possible at: http://cowles.econ.yale.edu/, see rubric 'Discussion Papers (CFDPs)' and http://www.econ.ucsd.edu/papers/files/90-4.pdf.

See Also

ur.pp, urca-class