Learn R Programming

urca (version 0.2-0)

ur.sp: Schmidt & Phillips Unit Root Test

Description

Performs the Schmidt & Phillips unit root test, where under the Null and Alternative Hypothesis the coefficients of the deterministic variables are included.

Usage

ur.sp(y, type = c("tau", "rho"), pol.deg = c(1, 2, 3, 4),
      signif = c(0.01, 0.05, 0.1))

Arguments

y
Vector to be tested for a unit root.
type
Test type, either tau or rho test.
pol.deg
Degree of polynomial in the test regression.
signif
Significance level for the critical value of the test statistic.

Value

  • An object of class "ur.sp".

Details

Under the Null and the Alternative hypothesis the coefficients of the deterministic part of the test regression are included. Two test types are available: the rho-test and the tau-test. Both test are extracted from the LM principle.

References

Schmidt, P. and Phillips, P.C.B. (1992), LM Test for a Unit Root in the Presence of Deterministic Trends, Oxford Bulletin of Economics and Statistics, 54(3), 257--287. Download possible at: http://cowles.econ.yale.edu/, see rubric 'Discussion Papers (CFDPs)'.

See Also

ur.sp-class

Examples

Run this code
data(nporg)
gnp <- na.omit(nporg[, "gnp.r"])
sp.gnp <- ur.sp(gnp, type="tau", pol.deg=1, signif=0.01)
summary(sp.gnp)

Run the code above in your browser using DataLab