Learn R Programming

urca (version 0.2-0)

urca-class: Class "urca". Parent of classes in package "urca"

Description

This class is the parent class of the specific classes designed holding the test specific information of the unit root/cointegration tests.

Arguments

Objects from the Class

Objects can be created by calls of the form new("urca", ...), but most often the slot test.name is set by calling one of the unit root functions, e.g ur.za.

Methods

No methods defined with class "urca".

See Also

ur.ers-class, ur.kpss-class, ca.po-class, ur.pp-class, ur.sp-class, ur.za-class for links to other classes.

Examples

Run this code
new("urca", test.name="Zivot-Andrews")

Run the code above in your browser using DataLab