ur.sp. It computes the critical value of the Schmidt &
Phillips test, given a level of significance, the polynomial degree of
the test regression, the test type and the sample size..spcv(obs, type = c("tau", "rho"), pol.deg = c(1, 2, 3, 4),
signif = c(0.01, 0.025, 0.05, 0.1))ur.sp