urca-class: Class "urca". Parent of classes in package "urca"
Description
This class is the parent class of the specific classes
designed holding the test specific information of the unit
root/cointegration tests.
Arguments
Objects from the Class
Objects can be created by calls of the form new("urca", ...),
but most often the slot test.name is set by calling one of the
unit root functions, e.gur.za.